sort_primary_key_indices

Function sort_primary_key_indices 

fn sort_primary_key_indices(
    primary_key: &DictionaryArray<UInt32Type>,
    timestamps: &[i64],
    sequences: &UInt64Array,
) -> Result<UInt32Array>
Computes sorted row indices by ranking dictionary values, scattering rows into primary-key buckets, and sorting only buckets that are not already ordered by time and sequence.