pub struct BulkPart {
pub batch: DfRecordBatch,
pub max_timestamp: i64,
pub min_timestamp: i64,
pub sequence: u64,
pub min_sequence: SequenceNumber,
pub timestamp_index: usize,
pub raw_data: Option<ArrowIpc>,
}Expand description
A raw bulk part in the memtable.
Fields
batch: DfRecordBatchmax_timestamp: i64min_timestamp: i64sequence: u64Uniform sequence for external bulk writes, or the maximum row sequence
for parts produced by BulkPartConverter. Rows need not share it.
min_sequence: SequenceNumberLower bound of row sequences. Slices may inherit a lower bound from their parent part rather than recomputing an exact minimum.
timestamp_index: usizeraw_data: Option<ArrowIpc>Implementations
Sourceimpl BulkPart
impl BulkPart
pub(crate) fn schema(&self) -> SchemaRef
pub(crate) fn estimated_size(&self) -> usize
Sourcepub fn estimated_series_count(&self) -> usize
pub fn estimated_series_count(&self) -> usize
Returns the estimated series count in this BulkPart. This is calculated from the dictionary values count of the PrimaryKeyArray.
Sourcepub fn to_memtable_stats(
&self,
region_metadata: &RegionMetadataRef,
) -> MemtableStats
pub fn to_memtable_stats( &self, region_metadata: &RegionMetadataRef, ) -> MemtableStats
Creates MemtableStats from this BulkPart.
Sourcepub fn fill_missing_columns(
&mut self,
region_metadata: &RegionMetadata,
) -> Result<()>
pub fn fill_missing_columns( &mut self, region_metadata: &RegionMetadata, ) -> Result<()>
Fills missing columns in the BulkPart batch with default values.
This function checks if the batch schema matches the region metadata schema, and if there are missing columns, it fills them with default values (or null for nullable columns).
Arguments
region_metadata- The region metadata containing the expected schema
Sourcepub(crate) fn to_mutation(
&self,
region_metadata: &RegionMetadataRef,
) -> Result<Mutation>
pub(crate) fn to_mutation( &self, region_metadata: &RegionMetadataRef, ) -> Result<Mutation>
Converts BulkPart to [Mutation] for fallback write_bulk implementation.
pub fn timestamps(&self) -> &ArrayRef
pub fn num_rows(&self) -> usize