pub(crate) fn should_prune_bulk_part(
batch: &DfRecordBatch,
context: &BulkIterContext,
metadata: &RegionMetadata,
) -> boolExpand description
Returns true if the batch should be pruned (skipped) based on the first-tag min/max statistics and the predicate in the context. Returns false if no pruning is possible (no primary key, no predicate, or the batch matches the predicate).